@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.2.19.0';
+our $VERSION = '1.2.20.0';
 
 use Exporter 'import';
 
@@ -97,7 +97,7 @@ $EXPORT_TAGS{standard} = [ @{ $EXPORT_TAGS{'ops'} },
 			   @{ $EXPORT_TAGS{'db'} },
 			   @{ $EXPORT_TAGS{'qpflags'} },
 			   @{ $EXPORT_TAGS{'qpstem'} } ];
-$EXPORT_TAGS{all} = [ @{ $EXPORT_TAGS{'standard'} }, @{ $EXPORT_TAGS{'enq_order'} } ];
+$EXPORT_TAGS{all} = [ @{ $EXPORT_TAGS{'standard'} }, @{ $EXPORT_TAGS{'enq_order'} }, 'BAD_VALUENO' ];
 
 
 # Names which can be exported.
@@ -441,9 +441,6 @@ ErrorHandler, standard ExpandDecider subclasses
 (user-defined ones works),
 user-defined weight classes.
 
-We don't yet wrap Xapian::Query::MatchAll, Xapian::Query::MatchNothing,
-or Xapian::BAD_VALUENO.
-
 =item Unwrapped methods
 
 The following methods are not yet wrapped:
